font-v
========

font-v is an open source font version string library (libfv) and executable (font-v) for reading, reporting, modifying, and writing OpenType name table ID 5 records and head table fontRevision records in *.otf and *.ttf fonts.  The application provides support for the OpenFV semantic font versioning specification.

font-v is built with Python and can be used on Linux, macOS, and Windows platforms with current versions of the Python 2 and Python 3 interpreters.

Source and documentation: https://github.com/source-foundry/font-v

libfv API documentation: https://font-v.readthedocs.io/en/latest/

Issue reporting: https://github.com/source-foundry/font-v/issues

OpenFV semantic font versioning specification - https://github.com/openfv/openfv

License: MIT
